lazy.build(filename, pdf.zip = NULL, quiet = TRUE, clean = TRUE,
replace = TRUE, ...)TRUE, extra files generated during processing will be deleted.pdf.zip is not NULL, this determines if
the new file will overwrite an existing file.tools::texi2dvitools::texi2dvi to
compile a PDF file.For HTML files, the referenced figures are gathered, copied into a subdirectory and the HTML document and the figures are placed into a zip folder for convenient transfer. All of the image links in the HTML code are modified to reflect the new location. Lastly, a text file is added with instructions for unzipping the files for convenient viewing (but don't worry, no one ever reads this).