Learn R Programming

lazyWeave (version 3.0.0)

lazy.citation: Add R or R Package Citation

Description

Generates code for the citation of R or an R package.

Usage

lazy.citation(pkg = NULL, author = TRUE, title = TRUE, org = TRUE,
  address = TRUE, volume = TRUE, year = TRUE, note = TRUE)

Arguments

pkg
a character(1) vector giving the name of a package. If NULL, a citation for R is produced.
author
Include author name
title
Include title of package
org
Include organization name
address
Include address
volume
Include volume
year
include year of publication
note
include the note on the citation.

Details

Not every option is populated in every package. Future improvements might include automatic detection of NULL fields, but for now, observing the output with all the options set to TRUE will tell you which ones are empty.

Examples

Run this code
lazy.citation()
lazy.citation(pkg="lazyWeave", org=FALSE, address=FALSE, volume=FALSE)

Run the code above in your browser using DataLab