Learn R Programming

lazyWeave (version 2.2.5)

lazy.footnote: Add a Footnote

Description

Adds a footnote to the text in a .tex file. In HTML files, an endnote is produced. Links are established between the text and the endnote for user convenience.

Usage

lazy.footnote(text, number=NULL, translate=FALSE,
              name, ref, counter="footnote", size=8)

Arguments

text
Text for the footnote.
number
Footnote number.
translate
Determines if latexTranslate is applied to text.
name
For HTML, a reference name to the endnote.
ref
For HTML, a reference name to go back to the text (from the endnote).
counter
For HTML, counter to use for numbering the endnotes.
size
For HTML, the text size to use for the endnote

Details

Be warned that this is not a perfect function on the LaTeX side. If you use special characters that require that latexTranslate be turned off, you'll also need to turn of latexTranslate in lazy.write. I'm including this as is for ease of use, but it does have some kinks to work out. name and ref are used to create links between the footnote marking in the text and the actual footnote. Clinking on the links created will allow the reader to go back and forth between them. The names may be similar, but exact matches may confuse the browser.

Examples

Run this code
lazy.footnote("Enter a reference to an article in this argument", number=3)
lazy.footnote(lazy.citation(), number=4)

Run the code above in your browser using DataLab