Learn R Programming

lazyWeave (version 3.0.0)

lazy.label: Reference Tables, Figures, Sections, and Pages

Description

Provides the code to label and reference objects that have a label statement with them

Usage

lazy.label(label)

lazy.ref(label, text, page = FALSE, link = TRUE)

Arguments

label
A character(1) giving the name of the to be created or referenced
text
For HTML, the text to be hyperlinked for the reference. If missing, this is set to "(link)"
page
Indicates if the page number on which the label lies should be returned or the object number. This only applies to LaTeX files
link
for LaTeX files, should the reference link to the object

Functions

  • lazy.label:

Examples

Run this code
lazy.label("Label1")
lazy.ref("Label1")
lazy.ref("Label1", page=TRUE)

Run the code above in your browser using DataLab