Learn R Programming

lazyWeave (version 2.2.5)

lazy.landscape: Landscape Page Orientation

Description

Allows the user to turn on or off landscape page orientation.

Usage

lazy.landscape(begin=TRUE)

Arguments

begin
If TRUE, begins the landscape environment. Otherwise, the environment is closed.

Value

  • Returns a string that either begins or ends a landscape environment.

Details

This function has no effect on HTML files. The page orientation is determined by the browser.

Examples

Run this code
lazy.landscape()
lazy.landscape(begin=FALSE)

Run the code above in your browser using DataLab