Learn R Programming

lazyWeave (version 2.2.0)

lazy.link: Links to Webpages or External Documents

Description

While lazy.ref provides the option of linking to areas within a document, lazy.link provides the option of linking to areas outside of the document. Web pages are perhaps the most obvious example, but links could also go to files on a directory.

Usage

lazy.link(url, text, web=TRUE, secure=FALSE)

Arguments

url
A character(1) giving the URL for the link or a file path.
text
The text to be highlighted as the link. If this is missing, url is used.
web
When TRUE, "http://" is added to url, (if not already present), to ensure a link to the web. For files on a local dis, set this to FALSE.
secure
Should the link be to a secure site "https://".

Examples

Run this code
lazy.label("Label1")
lazy.ref("Label1")
lazy.ref("Label1", page=TRUE)

Run the code above in your browser using DataLab