Usage
lazy.list(item, ordered = TRUE, counter = NULL, counterSet = 1,
title = NULL, style = c("arabic", "Roman", "roman", "Alph", "alph"),
symbol = c("bullet", "circ", "blacksquare"), font, family, size)Arguments
item
A vector with the items to be placed in the list
ordered
Denotes if the list is ordered or bulleted
counter
For future inclusion. Specifies what counter
should be used for numbering. Currently not in use
counterSet
The value to which counter should
be set. In other words, the number for the first item in the
list
title
A title for the list
style
A character string denoting how the ordered list
should be numbered. Options are "arabic", "roman",
"Roman", "alph", "Alph".
symbol
A symbol for bulleted lists to be used as the bullet
font
Font to be used in HTML documents. Defaults to the
font set in the options
family
Font family to be used in HTML documents. Defaults
to the font family in the options
size
Font size to be used in HTML documents. Defaults to
the font family in the options