lazy.page.number: Change Page Numbering
Description
Allows page numbering style to be changed. For instance, from roman numerals in an introduction
to arabic numbers in the body of a report.Usage
lazy.page.number(num_style = c("arabic", "roman", "Roman", "alph", "Alph"))Arguments
num_style
A character(1) giving the numbering style for the page
Details
Each time the page numbering is changed, the page counter is reset to 0 (meaning the next page will be numbered 1). If the number
needs to be preserved, this can be done using lazy.counter with counter="page".
This function has no effect on HTML files.