Learn R Programming

lazyWeave (version 2.1.3)

lazy.ref: Reference Tables, Figures, Sections, and Pages

Description

Provides the code to label and reference objects that have a label statement with them.

Usage

lazy.label(label)
lazy.ref(label, page=FALSE)

Arguments

label
A character(1) giving the name of the to be created or referenced.
page
Indicates if the page number on which the label lies should be returned or the object number.

Examples

Run this code
lazy.label("Label1")
lazy.ref("Label1")
lazy.ref("Label1", page=TRUE)

Run the code above in your browser using DataLab