Learn R Programming

lazyWeave (version 2.1.4)

lazy.verbatim: Verbatim Environments

Description

Text within a verbatim block appears exactly as type, including whitespace. This is useful when inserting code into a document.

Usage

lazy.verbatim.start()
lazy.verbatim.end()

Arguments

Details

A verbatim block takes any text entered and typsets it exactly as it was entered. White space is preserved and the font changes. This is typically done to display code, since the whitespace may preserve readability.