lazy.verbatim.end()lazy.verbatim.start()
lazy.verbatim.end:For HTML documents, this is done by opening a "
" tag with font family "monospace" and
font "courier". These are applicable until lazy.verbatim.end is called and the
"
It should be noted that HTML code in this forced environment will still not render whitespace as in the
LaTeX verbatim environment. This can be enforced by running the text in the environment through a function
like gsub("", "  ", [text]) (  is the HTML character for a non-breaking space).