Currently, there is no check to ensure that either variables submitted are factors. Data should be ordinal. Nominal data may not have any practical meaning in this test. Sometimes,
when a nominal variable has only two levels, this test may still be appropriate, i.e. Yes vs. No.
In 2xJ tables, when arbitrary scores (i.e., 0, 1) are applied to the rows and midranks applied to the
columns, this test is equivalent to the Wilcoxon, or Mann-Whitney test.
In Ix2 tables, when monotone scores are applied to the rows and abitrary scores applied to the columns,
this test is equivalent to the Cochran-Armitage test. See the reference for further details.