Learn R Programming

lazyWeave (version 2.2.0)

lazy.citation: Cite an R package

Description

Generates the text for a citation of R or an R package.

Usage

lazy.citation(pkg=NULL, author=TRUE, title=TRUE, org=TRUE, 
              address=TRUE, volume=TRUE, year=TRUE, note=TRUE)

Arguments

pkg
a character(1) vector giving the name of a package. If NULL, a citation for R is produced.
author
Include author name.
title
Include title of package.
org
Include organization.
address
Include address.
volume
Include volume.
year
Include year
note
Include note.

Details

Not every option is populated in every package. Future improvements might include automatic detection of NULL fields, but for now, observing the output with all the options set to TRUE will tell you which ones are empty.

Examples

Run this code
lazy.citation()
lazy.citation(pkg="Hmisc", org=FALSE, address=FALSE, volume=FALSE)

Run the code above in your browser using DataLab