Learn R Programming

lazyWeave (version 2.1.3)

lazy.footnote: Add a Footnote

Description

Adds a footnote to the text in a .tex file.

Usage

lazy.footnote(text, number=NULL, translate=FALSE)

Arguments

text
Text for the footnote.
number
Footnote number.
translate
Determines if latexTranslate is applied to text.

Details

Be warned that this is not a perfect function. If you use special characters that require that latexTranslate be turned off, you'll also need to turn of latexTranslate in lazy.write. I'm including this as is for ease of use, but it does have some kinks to work out.

Examples

Run this code
lazy.footnote("Enter a reference to an article in this argument", number=3)
lazy.footnote(lazy.citation(), number=4)

Run the code above in your browser using DataLab