Usage
lazy.matrix(x, align = "center", justify = "center", rcol = NULL,
usecol = "lightgray", caption = NULL, footnote = NULL,
placement = "h", translate = TRUE, cat = getOption("lazyWeave_cat"),
...)Arguments
x
A matrix. Other objects are coerced to matrices
align
Character vector or string giving the alignment for each
column of the table. Options are "left", "center", "right".
justify
Character string giving the alignment for the table on the
page. Options are "left", "center", "right".
rcol
A vector giving the rows of x to be colored
usecol
A character string or vector denoting the color of the rows
in rcol
caption
Caption for the table. This is printed above the table
footnote
Additional footnotes for the table. These are printed
below the table.
placement
Controls the placement of the figure. Options are
"ht", "t", "b", "p", "H" and can be supplemented with
"!". See "Details" for more explanation. These apply only to LaTeX
translate
Toggles if inputs in x should be passed through
latexTranslate. This should be set to FALSE if writing
custom code
cat
Logical. Determines if the output is returned as a character string
or returned via the cat function (printed to console). The default
value is set by options()$lazyWeave_cat. This argument allows for
selective override of the
...
Additional arguments to be passed to lazy.table